# -*- coding: utf8 -*-
from django.core import validators
from django.forms import Field, Widget
from django.template.loader import render_to_string

from .bbcode import BBCode


class BBCodeWidget(Widget):
    def __init__(self, attrs=None):
        super(BBCodeWidget, self).__init__(attrs)

    def render(self, name, value, attrs=None, renderer=None):
        bbcode_items = BBCode.valid_packs[self.attrs["bbcode_pack"]]

        if value is None:
            value = ""

        ctx = {
            "name": name,
            "value": value,
            "attrs": attrs,
            "items": bbcode_items,
        }

        return render_to_string("form_widgets/bbcode_field.html", ctx)

    class Media:
        js = ("bbcode/textarea.js", "bbcode/bbcode.js")


class BBCodeField(Field):
    default_error_messages = {"incorrect_value": "Imbrication des éléments BBCode incorrecte."}

    widget = BBCodeWidget

    def __init__(self, pack, *args, **kwargs):
        self.pack = pack
        super().__init__(*args, **kwargs)
        self.pack = pack

    @property
    def can_have_attachments(self):
        return self.pack.endswith("_attach")

    def widget_attrs(self, widget):
        if isinstance(widget, BBCodeWidget):
            return {
                "bbcode_pack": self.pack,
            }

    def to_python(self, value):
        if value in validators.EMPTY_VALUES:
            return None

        if not isinstance(value, BBCode):
            value = BBCode(self.pack, value, from_db=False)

        return value
